@@ -61,6 +61,8 @@ __workers__ = []
 __telegrambot_name__ = 'ht-bot'
 __telegrambot_token__ = ''
 
+__modulesLoadesThreadNames__ = []
+
 def __checkLibraryUpdate__():
     try:
         # Check Version Update
@@ -122,17 +124,22 @@ def getModule(moduleName):
     """
     #Logger.printMessage('Initiation of {moduleName}'.format(moduleName=moduleName), debug_module=True)
 
-    # While the mods are loading with workers, wait por it
-    print(getWorkers())
-    while any( [ work.startswith('import-module-') for work in getWorkers() ] ):
-        __sleep(0.1)
-
     for m in __modules_loaded__:
         if moduleName in m:
             if not 'ht_' in moduleName:
                 moduleName = 'ht_{m}'.format(m=moduleName)
             sentence = 'modules.{category}.{mod}.{moduleName}.StartModule()'.format(category=m.split('.')[1], mod='_'.join(moduleName.split('_')[1:]), moduleName=moduleName)
             return eval(sentence)
+
+    # Prevents any module not been fully loaded yet
+    if moduleName in __modulesLoadesThreadNames__:
+        for worker in getWorkers():
+            if moduleName in worker:
+                __sleep(0.1)
+                getModule(moduleName)
+                break
+        __modulesLoadesThreadNames__.remove(moduleName)
+
     Logger.printMessage('Looks like {mod} is not loaded on HackingTools. Look the first import in log. You could have some error in your code :)'.format(mod=moduleName), is_error=True)
 
 def getModules():
@@ -222,7 +229,6 @@ def wantPool():
     return __WANT_TO_BE_IN_POOL__
 
 def worker(workerName, functionCall, args=(), timesleep=1, loop=True, run_until_ht_stops=False, log=False, timeout=None):
-    print(workerName)
     Utils.startWorker(workerName, functionCall, args, int(timesleep), loop, run_until_ht_stops, log, timeout)
     if loop:
         __workers__.append(workerName)
@@ -539,6 +545,7 @@ def __importModule__(modules, category, moduleName):
                 __modules_loaded__[module_import_string_no_from][mod_func]['original_params'] = original_params if original_params else None
         else:
             __modules_loaded__[module_import_string_no_from] = 'Sin funciones...'
+        __modulesLoadesThreadNames__.remove(moduleName)
     except Exception as e:
         Logger.printMessage(str(e), is_error=True)
         new_module_name = str(e).split("'")[1]
@@ -582,8 +589,8 @@ def __importModules__():
             for files in modules[modu][submod]:
                 try:
                     module_name = modules[modu][submod][files][0].split(".")[0]
-                    print('__amidjango__', __amidjango__)
                     if not __amidjango__:
+                        __modulesLoadesThreadNames__.append(module_name)
                         worker("import-module-{m}".format(m=module_name), 'ht.__importModule__', args=(modu, submod, module_name), loop=False, log=False) # Threaded
                     else:
                         __importModule__(modules=modu, category=submod, moduleName=module_name)
